summaryrefslogtreecommitdiffstats
path: root/src/core/core.h
diff options
context:
space:
mode:
authorameerj <52414509+ameerj@users.noreply.github.com>2021-07-23 01:56:21 +0200
committerameerj <52414509+ameerj@users.noreply.github.com>2021-07-24 04:10:01 +0200
commit9dfbc9bdce15c299faf06aa7bf68a8660366daee (patch)
tree83ae648f51b4d0d2bb484741f86f5fb9bce8d00b /src/core/core.h
parentMerge pull request #6686 from ReinUsesLisp/vk-optimal-copy (diff)
downloadyuzu-9dfbc9bdce15c299faf06aa7bf68a8660366daee.tar
yuzu-9dfbc9bdce15c299faf06aa7bf68a8660366daee.tar.gz
yuzu-9dfbc9bdce15c299faf06aa7bf68a8660366daee.tar.bz2
yuzu-9dfbc9bdce15c299faf06aa7bf68a8660366daee.tar.lz
yuzu-9dfbc9bdce15c299faf06aa7bf68a8660366daee.tar.xz
yuzu-9dfbc9bdce15c299faf06aa7bf68a8660366daee.tar.zst
yuzu-9dfbc9bdce15c299faf06aa7bf68a8660366daee.zip
Diffstat (limited to '')
-rw-r--r--src/core/core.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/core/core.h b/src/core/core.h
index b93c32e60..ea143043c 100644
--- a/src/core/core.h
+++ b/src/core/core.h
@@ -94,7 +94,7 @@ class ARM_Interface;
class CpuManager;
class DeviceMemory;
class ExclusiveMonitor;
-class FrameLimiter;
+class SpeedLimiter;
class PerfStats;
class Reporter;
class TelemetrySession;
@@ -292,11 +292,11 @@ public:
/// Provides a constant reference to the internal PerfStats instance.
[[nodiscard]] const Core::PerfStats& GetPerfStats() const;
- /// Provides a reference to the frame limiter;
- [[nodiscard]] Core::FrameLimiter& FrameLimiter();
+ /// Provides a reference to the speed limiter;
+ [[nodiscard]] Core::SpeedLimiter& SpeedLimiter();
- /// Provides a constant referent to the frame limiter
- [[nodiscard]] const Core::FrameLimiter& FrameLimiter() const;
+ /// Provides a constant reference to the speed limiter
+ [[nodiscard]] const Core::SpeedLimiter& SpeedLimiter() const;
/// Gets the name of the current game
[[nodiscard]] Loader::ResultStatus GetGameName(std::string& out) const;